Spawn

Struct Spawn 

pub struct Spawn<'a, C = ()> { /* private fields */ }
Available on crate feature ecs only.
Composable to spawn an entity.

See spawn for more information.

Implementations

Source

impl<'a, C> Spawn<'a, C>

pub fn target(self, target: Entity) -> Self

Set the target entity to spawn the composition into.

If None, this will use the composition’s parent (if any).

pub fn content<C2>(self, content: C2) -> Spawn<'a, C2>

Set the child content.

pub fn on_spawn(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self

Add a function to be called when this bundle is initially spawned.

pub fn on_insert(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self

Add a function to be called on every insert.

pub fn observe<F, E, B, Marker>(self, observer: F) -> Self
where F: SystemParamFunction<Marker, In = On<'static, 'static, E, B>, Out = ()> + Send + Sync + 'a, E: EntityEvent, B: Bundle,

Add an observer to the spawned entity.