pub struct Spawn<'a, C = ()> { /* private fields */ }Available on crate feature
ecs only.Expand description
Composable to spawn an entity.
See spawn for more information.
Implementations
Sourceimpl<'a, C> Spawn<'a, C>
impl<'a, C> Spawn<'a, C>
Sourcepub fn target(self, target: Entity) -> Self
pub fn target(self, target: Entity) -> Self
Set the target entity to spawn the composition into.
If None, this will use the composition’s parent (if any).
Sourcepub fn on_spawn(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self
pub fn on_spawn(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self
Add a function to be called when this bundle is initially spawned.
Sourcepub fn on_insert(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self
pub fn on_insert(self, f: impl Fn(EntityWorldMut<'_>) + 'a) -> Self
Add a function to be called on every insert.
Sourcepub fn observe<F, E, B, Marker>(self, observer: F) -> Selfwhere
F: SystemParamFunction<Marker, In = On<'static, 'static, E, B>, Out = ()> + Send + Sync + 'a,
E: EntityEvent,
B: Bundle,
pub fn observe<F, E, B, Marker>(self, observer: F) -> Selfwhere
F: SystemParamFunction<Marker, In = On<'static, 'static, E, B>, Out = ()> + Send + Sync + 'a,
E: EntityEvent,
B: Bundle,
Add an observer to the spawned entity.